summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrFactory.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-01-22 19:55:40 -0600
committerTimothy Pearson <[email protected]>2013-01-22 19:55:40 -0600
commit73ff676f11662d6178c8854a7832ebffe2ae409d (patch)
tree9e89ea7d87940087d2d3c5db9b378ef989dd1346 /kpresenter/KPrFactory.h
parentc2ba2f56121c21a762619faf195e8332ef5b224f (diff)
downloadkoffice-73ff676f11662d6178c8854a7832ebffe2ae409d.tar.gz
koffice-73ff676f11662d6178c8854a7832ebffe2ae409d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kpresenter/KPrFactory.h')
-rw-r--r--kpresenter/KPrFactory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpresenter/KPrFactory.h b/kpresenter/KPrFactory.h
index 7e37bf6d..80763049 100644
--- a/kpresenter/KPrFactory.h
+++ b/kpresenter/KPrFactory.h
@@ -22,7 +22,7 @@
#define KPRESENTER_FACTORY_H
#include <KoFactory.h>
-class KAboutData;
+class TDEAboutData;
class KPrFactory : public KoFactory
{
@@ -36,14 +36,14 @@ public:
const char *name = 0, const char *classname = "KoDocument",
const TQStringList &args = TQStringList() );
- static KInstance* global();
+ static TDEInstance* global();
- // _Creates_ a KAboutData but doesn't keep ownership
- static KAboutData* aboutData();
+ // _Creates_ a TDEAboutData but doesn't keep ownership
+ static TDEAboutData* aboutData();
private:
- static KInstance* s_global;
- static KAboutData* s_aboutData;
+ static TDEInstance* s_global;
+ static TDEAboutData* s_aboutData;
};
#endif